class MageBlade {
	constructor(game, ox, oy, r, direction){
		this.game = game;
		
		// Rendering
		this.texture = game.textures.projectiles;
		this.map = game.atlas.projectiles.mageBlade;
		
		// Scale
		this.scale = 1;
		this.width = this.scale * 9;
		this.height = this.scale * 2;
		
		// Physics
		this.ox = ox;
		this.oy = oy;
		this.r = r;
		this.direction = direction;
		
		this.collision = {
			with: [ Alien ],
			width: this.width,
			height: this.height,
			radius: 0,
			offsetX: 0,
			offsetY: 0,
			hitRadius: 2,
			
			piercing: true,
			reaction: strongBurnReaction
		};
		
		// Mage Blade
		this.maxLife = 0.2;
		this.life = this.maxLife;
		this.isAlive = true;
	}
	
	
	update(delta){
		var distance = 16 * this.scale,
			offsetX = distance * Math.sin(this.r/180*Math.PI),
			offsetY = distance * -Math.cos(this.r/180*Math.PI);
		
		this.x = this.ox + offsetX;
		this.y = this.oy + offsetY;
		
		this.r += delta * this.direction * 400 * delta * 60;
		
		doCollision(this);
		this.isAlive = true;
		
		this.game.scene.addParticle(new MageBladeTrail(this.game, this.texture, this.map, this.x, this.y, this.r));
		
		if(!this.isAlive) return this.life = 0;
		return this.life -= delta;
	}
	
	
	draw(context, textures, atlas){
		var map = this.map,
			texture = this.texture;
		
		context.save();
		context.translate(this.x, this.y);
		context.rotate(this.r/180*Math.PI);
		
		context.drawImage(texture, map[0], map[1], map[2], map[3], -this.width/2, -this.height/2, this.width, this.height);
		
		context.restore();
	}
}
